@@ -3,10 +3,14 @@ require 'json'
 require 'net/http'
 require 'uri'
 
-json = Net::HTTP.get(URI('https://spdx.org/licenses/licenses.json'))
-licenses = JSON.parse(json)['licenses'].map do |licenseObject|
+licenses_json = Net::HTTP.get(URI('https://spdx.org/licenses/licenses.json'))
+licenses = JSON.parse(licenses_json)['licenses'].map do |licenseObject|
   licenseObject['licenseId']
 end
+exceptions_json = Net::HTTP.get(URI('https://spdx.org/licenses/exceptions.json'))
+exceptions = JSON.parse(exceptions_json)['exceptions'].map do |exceptionObject|
+  exceptionObject['licenseExceptionId']
+end
 
 open 'lib/rubygems/util/licenses.rb', 'w' do |io|
   io.write <<-RUBY
@@ -20,16 +24,21 @@ class Gem::Licenses
 
   # Software Package Data Exchange (SPDX) standard open-source software
   # license identifiers
-  IDENTIFIERS = %w(
+  LICENSE_IDENTIFIERS = %w(
       #{licenses.sort.join "\n      "}
   ).freeze
 
+  # exception identifiers
+  EXCEPTION_IDENTIFIERS = %w(
+      #{exceptions.sort.join "\n      "}
+  ).freeze
+
   REGEXP = %r{
     \\A
     (
-      \#{Regexp.union(IDENTIFIERS)}
+      \#{Regexp.union(LICENSE_IDENTIFIERS)}
       \\+?
-      (\\s WITH \\s .+)?
+      (\\s WITH \\s \#{Regexp.union(EXCEPTION_IDENTIFIERS)})?
       | \#{NONSTANDARD}
     )
     \\Z
@@ -40,7 +49,7 @@ class Gem::Licenses
   end
 
   def self.suggestions(license)
-    by_distance = IDENTIFIERS.group_by do |identifier|
+    by_distance = LICENSE_IDENTIFIERS.group_by do |identifier|
       levenshtein_distance(identifier, license)
     end
     lowest = by_distance.keys.min
